==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/FilterStringErrorsParsingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FilterStringErrorsParsingEventArgsDescription } from "./FilterStringErrorsParsingEventArgsDescription";
/**
 * @hidden
 */
export let FilterStringErrorsParsingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class FilterStringErrorsParsingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (FilterStringErrorsParsingEventArgsDescriptionMetadata.a == null) {
                FilterStringErrorsParsingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FilterStringErrorsParsingEventArgsDescriptionMetadata.c(FilterStringErrorsParsingEventArgsDescriptionMetadata.a);
            }
            if (a.k(FilterStringErrorsParsingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(FilterStringErrorsParsingEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("PropertyName", "String");
            a.item("Errors", "String");
        }
        static d(a) {
            FilterStringErrorsParsingEventArgsDescriptionMetadata.b(a);
            a.ad("FilterStringErrorsParsingEventArgs", () => new FilterStringErrorsParsingEventArgsDescription());
            a.ac("FilterStringErrorsParsingEventArgs", FilterStringErrorsParsingEventArgsDescriptionMetadata.a);
        }
    }
    FilterStringErrorsParsingEventArgsDescriptionMetadata.$t = markType(FilterStringErrorsParsingEventArgsDescriptionMetadata, 'FilterStringErrorsParsingEventArgsDescriptionMetadata');
    FilterStringErrorsParsingEventArgsDescriptionMetadata.a = null;
    return FilterStringErrorsParsingEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/FilterStringErrorsParsingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FilterStringErrorsParsingEventArgsDescription } from "./FilterStringErrorsParsingEventArgsDescription";
/**
 * @hidden
 */
export let FilterStringErrorsParsingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class FilterStringErrorsParsingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (FilterStringErrorsParsingEventArgsDescriptionMetadata.a == null) {
                FilterStringErrorsParsingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FilterStringErrorsParsingEventArgsDescriptionMetadata.c(FilterStringErrorsParsingEventArgsDescriptionMetadata.a);
            }
            if (a.k(FilterStringErrorsParsingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(FilterStringErrorsParsingEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("PropertyName", "String");
            a.item("Errors", "String");
        }
        static d(a) {
            FilterStringErrorsParsingEventArgsDescriptionMetadata.b(a);
            a.ae("FilterStringErrorsParsingEventArgs", () => new FilterStringErrorsParsingEventArgsDescription());
            a.ad("FilterStringErrorsParsingEventArgs", FilterStringErrorsParsingEventArgsDescriptionMetadata.a);
        }
    }
    FilterStringErrorsParsingEventArgsDescriptionMetadata.$t = markType(FilterStringErrorsParsingEventArgsDescriptionMetadata, 'FilterStringErrorsParsingEventArgsDescriptionMetadata');
    FilterStringErrorsParsingEventArgsDescriptionMetadata.a = null;
    return FilterStringErrorsParsingEventArgsDescriptionMetadata;
})();
